# CORSOrigin

Describes an origin to allow for Cross-Origin Resource Sharing. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**exact** | **str** | An exact origin to match. Note that this includes the scheme as well as the host. Typically origins do not include the path.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


